@@ -20,21 +20,24 @@ def get_ecses():
 def cli():
     ecses = get_ecses()
     while True:
-        os.system('clear')
-        for i in range(len(ecses)):
-            print(''.join([str(i+1), ':', ecses[i].__str__()]))
+        try:
+            os.system('clear')
+            for i in range(len(ecses)):
+                print(''.join([str(i + 1), ':', ecses[i].__str__()]))
 
-        indexstr=input('请选择ECS序号:')
-        if not indexstr.isdigit():
-            continue
-        if int(indexstr)>len(ecses):
-            continue
+            indexstr = input('请选择ECS序号:')
+            if not isinstance(indexstr, int):
+                continue
+            if int(indexstr) > len(ecses):
+                continue
 
-        cur_ecs=ecses[int(indexstr)-1]
-        sship = cur_ecs.ip
-        # sship = '127.0.0.1'
-        print('ecs',':',cur_ecs.__str__())
-        os.system('ssh ' + sship)
+            cur_ecs = ecses[int(indexstr) - 1]
+            sship = cur_ecs.ip
+            # sship = '127.0.0.1'
+            print('ecs', ':', cur_ecs.__str__())
+            os.system('ssh ' + sship)
+        except SyntaxError as e:
+            pass
 
 
 if __name__ == '__main__':
