@@ -11,11 +11,11 @@ if not os.path.exists(ini_file_dir):
 
 if not os.path.exists(ini_file):
     cfg = ConfigParser.RawConfigParser()
-    cfg.add_section('default')
-    # cfg.set('default','accesskeyid','')
-    cfg.set('default','accesskeyid',input('请输入accesskeyid:'))
-    cfg.set('default','accesskeysecret',input('accesskeysecret:'))
-    cfg.set('default','regionids',input('请输入regionids(","分隔):'))
+    cfg.add_section('config')
+    # cfg.set('config','accesskeyid','')
+    cfg.set('config','accesskeyid',input('请输入accesskeyid:'))
+    cfg.set('config','accesskeysecret',input('accesskeysecret:'))
+    cfg.set('config','regionids',input('请输入regionids(","分隔):'))
     print('需要在配置文件中设置相应值,配置文件：',ini_file)
     with open (ini_file,'+w') as f:
         cfg.write(f)
